@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+import os
 import subprocess
 from getpass import getpass
 from pathlib import Path
@@ -8,7 +9,7 @@ from colorama import Style
 
 from isisdl.backend.crypt import get_credentials, store_user
 from isisdl.backend.request_helper import RequestHelper, SessionWithKey
-from isisdl.settings import is_online, error_text
+from isisdl.settings import is_online, error_text, forbidden_chars
 from isisdl.settings import is_windows, systemd_timer_file_location, working_dir_location, is_static
 from isisdl.utils import get_input, User, clear, config, on_kill, remove_systemd_timer, logger, install_systemd_timer, database_helper, sanitize_name
 
@@ -125,10 +126,6 @@ def authentication_prompt() -> None:
 
 def filename_prompt() -> None:
     clear()
-    if is_windows:
-        forbidden_chars = "<>:\"/\\|?*"
-    else:
-        forbidden_chars = "/"
 
     print(f"""Some programs / programming languages have restrictions or
 inconveniences when it comes to working with special characters.
@@ -142,9 +139,10 @@ the next character after a whitespace is capitalized.
 For example:
 "I am / a \\ wierd 🐧 [filename].png" → "IAmAWierdFilename.png"
 
+Would you like to enable this option?
 
 --- Note ---
-The character{'s' if is_windows else ''} `{forbidden_chars}` {'are' if is_windows else 'is'} always replaced (not supported on a filesystem level).
+The character{'s' if len(forbidden_chars) > 1 else ''} `{forbidden_chars}` {'are' if len(forbidden_chars) > 1 else 'is'} always replaced (not supported on a filesystem level).
 
 Changing this option after initial configuration is not supported (yet).
 ------------
@@ -679,6 +677,60 @@ vs
     bool_prompt("absolute_path_filename")
 
 
+def ask_completions_prompt() -> None:
+    clear()
+    # TODO: Check if completions are available
+
+    shell = os.environ['SHELL']
+    is_zsh = "zsh" in shell
+    is_fish = "fish" in shell
+    is_bash = "bash" in shell
+
+    if is_zsh:
+        # completion = subprocess.check_output([shell, "-c", "echo $_comps[isisdl]"])
+        pass
+
+    elif is_fish:
+        pass
+
+    elif is_bash:
+        pass
+
+    print(f"""There are tab-completions available for your shell: {shell}
+
+However, the prerequisites for this shell are not fulfilled.""")
+
+    path_dir = "TODO"
+
+    if is_zsh:
+        print(f"""The FPATH does not contain the directory for the isisdl completions.
+In order to use them you must add the following to your ~/.zshrc:
+
+export FPATH=$FPATH:{path_dir}
+
+If you wish, I can also do that for you. Do you want me to add this to your config?
+""")
+
+    if is_fish:
+        print("""In order for you to use the completions all of your system manpages have to be parsed.
+This will take a considerable amount of time (~20s). You can manually regerage them by executing the following command:
+
+`fish_update_completions`
+
+If you wish, I can also do that for you. Should I do that?""")
+
+        if True:
+            os.system("fish_update_completions")
+
+    if is_bash:
+        print(f"""In order for you to use the completions the following command has to be added to your ~/.bashrc:
+
+source {path_dir}
+
+If you wish, I can also do that for you. Do you want me to add this to your config?""")
+
+
+# TODO: Add tab completion prompt
 def init_wizard() -> None:
     global was_in_configuration
     was_in_configuration = True
@@ -698,6 +750,7 @@ def config_wizard() -> None:
     global was_in_configuration
     was_in_configuration = True
 
+    # ask_completions_prompt()
     throttler_prompt()
     dont_download_videos_prompt()
     whitelist_prompt()
