@@ -381,12 +381,11 @@ class MediaContainer:
 
             if is_testing:
                 if media_type == MediaType.corrupted:
-                    assert size == 0
+                    assert size == 0 or size == -1 or size is None
                 else:
                     assert size != 0 and size != -1
 
-            return cls(name, container.url, download_url or container.url, container.parent_path.joinpath(sanitize_name(name, False)), time, container.course, media_type, size,
-                       _newly_discovered=True).dump()
+            return cls(name, container.url, download_url or container.url, container.parent_path.joinpath(sanitize_name(name, False)), time, container.course, media_type, size, _newly_discovered=True).dump()
 
         finally:
             container.is_cached = True
@@ -1001,7 +1000,7 @@ def check_for_conflicts_in_files(files: List[MediaContainer]) -> List[MediaConta
     # Now check for files with the same size in each course
     hard_link_conflicts: DefaultDict[str, List[MediaContainer]] = defaultdict(list)
 
-    for file in {file.path: file for file in files}.values():
+    for file in new_files:
         hard_link_conflicts[f"{file.course.course_id} {file._name} {file.size}"].append(file)
 
     new_files = []
