@@ -34,7 +34,7 @@ import colorama
 import distro as distro
 import requests
 from packaging import version
-from packaging.version import Version, LegacyVersion
+from packaging.version import Version
 from requests import Session
 
 from isisdl import settings
@@ -84,7 +84,7 @@ def get_args() -> argparse.Namespace:
     try:
         return parser.parse_args()
     except SystemExit as ex:
-        os._exit(ex.code)
+        os._exit(int(ex.code or 1))
 
 
 class Config:
@@ -613,7 +613,7 @@ def is_h265(file: Path) -> Optional[bool]:
     return bool(video_stream["codec_name"] == "hevc")
 
 
-def check_pypi_for_version() -> Optional[Union[LegacyVersion, Version]]:
+def check_pypi_for_version() -> Optional[Version]:
     # Inspired from https://pypi.org/project/pypi-search
     to_search = requests.get("https://pypi.org/project/isisdl/").text
     found_version = re.search("<h1 class=\"package-header__name\">\n *(.*)?\n *</h1>", to_search)
@@ -628,7 +628,7 @@ def check_pypi_for_version() -> Optional[Union[LegacyVersion, Version]]:
     return version.parse(groups[0].split()[1])
 
 
-def check_github_for_version() -> Optional[Union[LegacyVersion, Version]]:
+def check_github_for_version() -> Optional[Version]:
     if is_static:
         latest_release = requests.get("https://api.github.com/repos/Emily3403/isisdl/releases/latest").json()
         if "tag_name" not in latest_release:
@@ -652,10 +652,8 @@ def check_github_for_version() -> Optional[Union[LegacyVersion, Version]]:
         return version.parse(found_version.group(1))
 
 
-def print_changelog_for_version(new_version: Union[LegacyVersion, Version]) -> None:
+def print_changelog_for_version(new_version: Version) -> None:
     current_version = version.parse(__version__)
-    assert not isinstance(current_version, LegacyVersion)
-    assert not isinstance(new_version, LegacyVersion)
 
     for i in range(current_version.micro + 1, new_version.micro + 1):
         con = requests.get(f"https://raw.githubusercontent.com/Emily3403/isisdl/main/src/isisdl/resources/changelog/"
